package com.srs.comprehensive.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.srs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.srs.comprehensive.mapper.CphMsgMapper;
import com.srs.comprehensive.domain.CphMsg;
import com.srs.comprehensive.service.ICphMsgService;

/**
 * 消息Service业务层处理
 *
 * @author srs
 * @date 2023-07-12
 */
@Service
public class CphMsgServiceImpl extends ServiceImpl<CphMsgMapper,CphMsg> implements ICphMsgService
{
    @Autowired
    private CphMsgMapper cphMsgMapper;

    /**
     * 查询消息
     *
     * @param id 消息主键
     * @return 消息
     */
    @Override
    public CphMsg selectCphMsgById(Long id)
    {
        return cphMsgMapper.selectCphMsgById(id);
    }

    /**
     * 查询消息列表
     *
     * @param cphMsg 消息
     * @return 消息
     */
    @Override
    public List<CphMsg> selectCphMsgList(CphMsg cphMsg)
    {
        return cphMsgMapper.selectCphMsgList(cphMsg);
    }

    /**
     * 新增消息
     *
     * @param cphMsg 消息
     * @return 结果
     */
    @Override
    public int insertCphMsg(CphMsg cphMsg)
    {
        cphMsg.setCreateTime(DateUtils.getNowDate());
        return cphMsgMapper.insertCphMsg(cphMsg);
    }

    /**
     * 修改消息
     *
     * @param cphMsg 消息
     * @return 结果
     */
    @Override
    public int updateCphMsg(CphMsg cphMsg)
    {
        cphMsg.setUpdateTime(DateUtils.getNowDate());
        return cphMsgMapper.updateCphMsg(cphMsg);
    }

    /**
     * 批量删除消息
     *
     * @param ids 需要删除的消息主键
     * @return 结果
     */
    @Override
    public int deleteCphMsgByIds(Long[] ids)
    {
        return cphMsgMapper.deleteCphMsgByIds(ids);
    }

    /**
     * 删除消息信息
     *
     * @param id 消息主键
     * @return 结果
     */
    @Override
    public int deleteCphMsgById(Long id)
    {
        return cphMsgMapper.deleteCphMsgById(id);
    }
    /**
     * 删除消息信息
     *
     * @param cphMsg 消息
     * @return 结果
     */
    @Override
    public List<CphMsg> selectCphMsgListForFlowable(CphMsg cphMsg) {
        return cphMsgMapper.selectCphMsgListForFlowable(cphMsg);
    }

    /**
     * 根据学号查询用户ID
     *
     * @param stuNo 学号
     * @return 用户ID
     */
    @Override
    public Long getUserIdByStuNo(String stuNo)
    {
        return cphMsgMapper.getUserIdByStuNo(stuNo);
    }
}
